@@ -8,7 +8,7 @@ use strict;
 
 use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS $VERSION %HTLC_COLORS);
 
-$VERSION = '0.64';
+$VERSION = '0.65';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -32,18 +32,19 @@ HTLC_INFO_FOLDER_TYPE HTLC_MACOS_TO_UNIX_TIME HTLC_MAGIC HTLC_MAGIC_LEN
 HTLC_MAX_PATHLEN HTLC_NEWLINE HTLC_PATH_SEPARATOR HTLC_TASK_FILE_DELETE
 HTLC_TASK_FILE_GET HTLC_TASK_FILE_INFO HTLC_TASK_FILE_LIST
 HTLC_TASK_FILE_MKDIR HTLC_TASK_FILE_MOVE HTLC_TASK_FILE_PUT HTLC_TASK_KICK
-HTLC_TASK_LOGIN HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_SEND_MSG
-HTLC_TASK_SET_INFO HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST
-HTLC_UNIX_TO_MACOS_TIME HTLS_DATA_AGREEMENT HTLS_DATA_CHAT HTLS_DATA_COLOR
-HTLS_DATA_FILE_COMMENT HTLS_DATA_FILE_CREATOR HTLS_DATA_FILE_CTIME
-HTLS_DATA_FILE_ICON HTLS_DATA_FILE_LIST HTLS_DATA_FILE_MTIME
-HTLS_DATA_FILE_NAME HTLS_DATA_FILE_SIZE HTLS_DATA_FILE_TYPE
-HTLS_DATA_HTXF_REF HTLS_DATA_HTXF_SIZE HTLS_DATA_ICON HTLS_DATA_MSG
-HTLS_DATA_NEWS HTLS_DATA_NEWS_POST HTLS_DATA_NICKNAME HTLS_DATA_PCHAT_REF
+HTLC_TASK_LOGIN HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_PCHAT_ACCEPT
+HTLC_TASK_PCHAT_CREATE HTLC_TASK_SEND_MSG HTLC_TASK_SET_INFO
+HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST HTLC_UNIX_TO_MACOS_TIME
+HTLS_DATA_AGREEMENT HTLS_DATA_CHAT HTLS_DATA_COLOR HTLS_DATA_FILE_COMMENT
+HTLS_DATA_FILE_CREATOR HTLS_DATA_FILE_CTIME HTLS_DATA_FILE_ICON
+HTLS_DATA_FILE_LIST HTLS_DATA_FILE_MTIME HTLS_DATA_FILE_NAME
+HTLS_DATA_FILE_SIZE HTLS_DATA_FILE_TYPE HTLS_DATA_HTXF_REF
+HTLS_DATA_HTXF_SIZE HTLS_DATA_ICON HTLS_DATA_MSG HTLS_DATA_NEWS
+HTLS_DATA_NEWS_POST HTLS_DATA_NICKNAME HTLS_DATA_PCHAT_REF
 HTLS_DATA_PCHAT_SUBJECT HTLS_DATA_SERVER_MSG HTLS_DATA_SOCKET
 HTLS_DATA_TASK_ERROR HTLS_DATA_USER_INFO HTLS_DATA_USER_LIST
 HTLS_HDR_AGREEMENT HTLS_HDR_CHAT HTLS_HDR_MSG HTLS_HDR_NEWS_POST
-HTLS_HDR_PCHAT_INVITE HTLS_HDR_PCHAT_SUBJECT HTLS_HDR_PCHAT_USER_CHANGE
+HTLS_HDR_PCHAT_INVITE HTLS_HDR_PCHAT_SUBJECT HTLS_HDR_PCHAT_USER_JOIN
 HTLS_HDR_PCHAT_USER_LEAVE HTLS_HDR_POLITE_QUIT HTLS_HDR_TASK
 HTLS_HDR_USER_CHANGE HTLS_HDR_USER_LEAVE HTLS_MAGIC HTLS_MAGIC_LEN
 HTLS_TCPPORT HTRK_MAGIC HTRK_MAGIC_LEN HTRK_TCPPORT HTRK_UDPPORT
@@ -88,22 +89,23 @@ use constant HTLC_EWOULDBLOCK      => 2; # Can be anything > 1, really
 use constant HTLC_MAX_PATHLEN      => 255;
 
 # Arbitrary unique task type constants
-use constant HTLC_TASK_FILE_DELETE => 1;
-use constant HTLC_TASK_FILE_GET    => 2;
-use constant HTLC_TASK_FILE_INFO   => 3;
-use constant HTLC_TASK_FILE_LIST   => 4;
-use constant HTLC_TASK_FILE_MKDIR  => 5;
-use constant HTLC_TASK_FILE_MOVE   => 6;
-use constant HTLC_TASK_FILE_PUT    => 7;
-use constant HTLC_TASK_KICK        => 8;
-use constant HTLC_TASK_LOGIN       => 9;
-use constant HTLC_TASK_NEWS        => 10;
-use constant HTLC_TASK_NEWS_POST   => 11;
-use constant HTLC_TASK_SEND_MSG    => 12;
-use constant HTLC_TASK_SET_INFO    => 13;
-use constant HTLC_TASK_USER_INFO   => 14;
-use constant HTLC_TASK_USER_LIST   => 15;
-
+use constant HTLC_TASK_FILE_DELETE  => 1;
+use constant HTLC_TASK_FILE_GET     => 2;
+use constant HTLC_TASK_FILE_INFO    => 3;
+use constant HTLC_TASK_FILE_LIST    => 4;
+use constant HTLC_TASK_FILE_MKDIR   => 5;
+use constant HTLC_TASK_FILE_MOVE    => 6;
+use constant HTLC_TASK_FILE_PUT     => 7;
+use constant HTLC_TASK_KICK         => 8;
+use constant HTLC_TASK_LOGIN        => 9;
+use constant HTLC_TASK_NEWS         => 10;
+use constant HTLC_TASK_NEWS_POST    => 11;
+use constant HTLC_TASK_SEND_MSG     => 12;
+use constant HTLC_TASK_SET_INFO     => 13;
+use constant HTLC_TASK_USER_INFO    => 14;
+use constant HTLC_TASK_USER_LIST    => 15;
+use constant HTLC_TASK_PCHAT_CREATE => 16;
+use constant HTLC_TASK_PCHAT_ACCEPT => 17;
 
 use constant HTRK_TCPPORT   => 5498;
 use constant HTRK_UDPPORT   => 5499;
@@ -114,15 +116,15 @@ use constant HTXF_BUFSIZE   => 4096;
 
 use constant HTLC_NEWLINE   => "\015";
 
-use constant HTLC_MAGIC        => pack("c12", 84, 82, 84, 80, 72, 79, 84, 76, 0, 1, 0, 2);
+use constant HTLC_MAGIC        => pack("C12", 84, 82, 84, 80, 72, 79, 84, 76, 0, 1, 0, 2);
 use constant HTLC_MAGIC_LEN    => 12;
-use constant HTLS_MAGIC        => pack("c8", 84, 82, 84, 80, 0, 0, 0, 0);
+use constant HTLS_MAGIC        => pack("C8", 84, 82, 84, 80, 0, 0, 0, 0);
 use constant HTLS_MAGIC_LEN    => 8;
-use constant HTRK_MAGIC	       => pack("c6", 72, 84, 82, 75, 0, 1);
+use constant HTRK_MAGIC	       => pack("C6", 72, 84, 82, 75, 0, 1);
 use constant HTRK_MAGIC_LEN    => 6;
-use constant HTXF_MAGIC	       => pack("c4", 72, 84, 88, 70);
+use constant HTXF_MAGIC	       => pack("C4", 72, 84, 88, 70);
 use constant HTXF_MAGIC_LEN    => 4;
-use constant HTXF_RFLT_MAGIC   => pack("c4", 82, 70, 76, 84);
+use constant HTXF_RFLT_MAGIC   => pack("C4", 82, 70, 76, 84);
 use constant HTXF_RESUME_MAGIC => pack("n3", 0x00CC, 0x0002, 0x0001);
 
 use constant HTLC_HDR_CHAT              => 0x00000069;
@@ -176,7 +178,7 @@ use constant HTLS_HDR_MSG               => 0x00000068;
 use constant HTLS_HDR_NEWS_POST         => 0x00000066;
 use constant HTLS_HDR_PCHAT_INVITE      => 0x00000071;
 use constant HTLS_HDR_PCHAT_SUBJECT     => 0x00000077;
-use constant HTLS_HDR_PCHAT_USER_CHANGE => 0x00000075;
+use constant HTLS_HDR_PCHAT_USER_JOIN   => 0x00000075;
 use constant HTLS_HDR_PCHAT_USER_LEAVE  => 0x00000076;
 use constant HTLS_HDR_POLITE_QUIT       => 0x0000006F;
 use constant HTLS_HDR_TASK              => 0x00010000;
