@@ -8,7 +8,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.64';
+$VERSION = '0.65';
 
 sub new
 {
@@ -32,49 +32,49 @@ sub new
 
 sub icon
 {
-  $_[0]->{'TYPE'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'TYPE'} = $_[1]  if(@_ == 2);
   return $_[0]->{'TYPE'};
 }
 
 sub type
 {
-  $_[0]->{'TYPE'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'TYPE'} = $_[1]  if(@_ == 2);
   return $_[0]->{'TYPE'};
 }
 
 sub creator
 {
-  $_[0]->{'CREATOR'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'CREATOR'} = $_[1]  if(@_ == 2);
   return $_[0]->{'CREATOR'};
 }
 
 sub size
 {
-  $_[0]->{'SIZE'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'SIZE'} = $_[1]  if(@_ == 2);
   return $_[0]->{'SIZE'};
 }
 
 sub name
 {
-  $_[0]->{'NAME'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'NAME'} = $_[1]  if(@_ == 2);
   return $_[0]->{'NAME'};
 }
 
 sub comment
 {
-  $_[0]->{'COMMENT'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'COMMENT'} = $_[1]  if(@_ == 2);
   return $_[0]->{'COMMENT'};
 }
 
 sub ctime
 {
-  $_[0]->{'CTIME'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'CTIME'} = $_[1]  if(@_ == 2);
   return $_[0]->{'CTIME'};
 }
 
 sub mtime
 {
-  $_[0]->{'MTIME'} = $_[1]  if(defined($_[1]));
+  $_[0]->{'MTIME'} = $_[1]  if(@_ == 2);
   return $_[0]->{'MTIME'};
 }
 
